import { Suspense } from "react";

import { AboutLoadingSkeleton } from "@/components/common/loading-skeleton";
import Footer from "@/components/layout/footer";
import Header from "@/components/layout/header-2/header-2";
import About from "@/components/sections/about/about";
import FAQs from "@/components/sections/about/faqs";
import ServicesList from "@/components/sections/about/services";
import { ValuesClient } from "@/components/sections/about/values";
import VideoProfile from "@/components/sections/about/video-profile";
import Features from "@/components/sections/home/features";
import Statistics from "@/components/sections/home/statistics";
import { PageBreadcrumb } from "@/components/shared/page-breadcrump";
import { ImageBaseUrl } from "@/configs/api";
import { Locale } from "@/i18n/routing";
import { getClient } from "@/lib/react-query";
import { fetchBasicInfo } from "@/servers/actions/basicinfo-action";
import { fetchProjects } from "@/servers/actions/project-action";
import { dehydrate, HydrationBoundary } from "@tanstack/react-query";
import { getLocale } from "next-intl/server";

export default async function AboutPage() {
	const locale = await getLocale() as Locale;
	const breadcrumbItems = [
		{
			href: "/",
			label: {
				en: "Home",
				ar: "الرئيسية",
			},
		},
		{
			href: "/about",
			label: {
				en: "About Us",
				ar: "من نحن",
			},
		},
	];


	const queryClient = getClient();

	await Promise.all([
		queryClient.prefetchQuery({ queryKey: ["basicInfo"], queryFn: fetchBasicInfo }),
		queryClient.prefetchQuery({ queryKey: ["projects"], queryFn: fetchProjects }),

	]);


	const _data = queryClient.getQueryData<any>(["basicInfo"]);

	const about = _data?.data?.pages_headers?.find((val: any) => val.page == "about");


	return (
		<HydrationBoundary state={dehydrate(queryClient)}>
			<main className="min-h-screen">
				<Header />
				<Suspense fallback={<AboutLoadingSkeleton locale={locale} />}>
					<PageBreadcrumb
						backgroundImage={ImageBaseUrl + about?.page_image}
						subtitle={{
							en: about?.text?.en,
							ar: about?.text?.ar,
						}}
						title={{
							en: about?.description?.en,
							ar: about?.description?.ar,
						}}
						breadcrumbItems={breadcrumbItems}
						locale={locale}
					/>
					<About />
					<Statistics />
					<Features />
					<VideoProfile />
					<ValuesClient />
					<ServicesList />
					<FAQs />
					<Footer />
				</Suspense>
			</main>
		</HydrationBoundary>
	);
}
